@@ -248,8 +248,6 @@ struct _XklConfigRegistryPrivate {
 	xmlDocPtr doc;
 
 	xmlXPathContextPtr xpath_context;
-
-	const gchar *custom_charset;
 };
 
 extern void xkl_engine_ensure_vtable_inited(XklEngine * engine);
@@ -338,10 +336,6 @@ extern void xkl_engine_try_call_state_func(XklEngine * engine,
 					   change_type,
 					   XklState * old_state);
 
-extern void xkl_i18n_init(void);
-
-extern gint xkl_get_language_priority(const gchar * language);
-
 extern gchar *xkl_engine_get_ruleset_name(XklEngine * engine,
 					  const gchar default_ruleset[]);
 
